@@ -1,5 +1,5 @@
 #
-# $Id: FS.pm,v 1.5 2003/09/02 20:34:31 wpm Exp $
+# $Id: FS.pm,v 2.6 2003/09/29 18:08:10 wpm Exp $
 #
 # (c) 2003 Morgan Stanley and Co.
 # See ..../src/LICENSE for terms of distribution.
@@ -21,7 +21,7 @@ use AFS::Object::Server;
 use AFS::Object::ACL;
 
 our @ISA = qw(AFS::Command::Base);
-our $VERSION = '1.0';
+our $VERSION = '1.1';
 
 sub checkservers {
 
@@ -139,6 +139,7 @@ sub _paths_method {
 	my $path = AFS::Object::Path->new();
 
 	if ( /fs: Invalid argument; it is possible that (.*) is not in AFS./ ||
+	     /fs: no such cell as \'(.*)\'/ ||
 	     /fs: File \'(.*)\' doesn\'t exist/ ||
 	     /fs: You don\'t have the required access rights on \'(.*)\'/ ) {
 
@@ -385,13 +386,18 @@ sub _paths_method {
 		$path->_setAttribute( asynchrony => $default );
 	    }
 	}
-
     }
 
-    if ( keys %paths ) {
-	$self->_Carp("fs $operation: Unable to determine results for the following paths:\n\t" .
-		     join("\n\t", sort keys %paths) . "\n");
-	$errors++;
+    foreach my $pathname ( keys %paths ) {
+
+	my $path = AFS::Object::Path->new
+	  (
+	   path			=> $pathname,
+	   error		=> "Unable to determine results",
+	  );
+
+	$result->_addPath($path);
+
     }
 
     $errors++ unless $self->_reap_cmds( allowstatus => 1 );
@@ -747,7 +753,9 @@ sub lsmount {
 
 	my $path = AFS::Object::Path->new( path => $current );
 
-	if ( /fs: Can\'t read target name/ ) {
+	if ( /fs: Can.t read target name/ ) {
+	    $path->_setAttribute( error => $_ );
+	} elsif ( /fs: File '.*' doesn't exist/ ) {
 	    $path->_setAttribute( error => $_ );
 	} elsif ( /fs: you may not use \'.\'/ ) {
 	    $_ .= $self->{handle}->getline();
@@ -779,10 +787,13 @@ sub lsmount {
 
     }
 
-    if ( keys %dirs ) {
-	$self->_Carp("fs lsmount: Unable to determine results for the following paths:\n\t" .
-		     join("\n\t", sort keys %dirs) . "\n");
-	$errors++;
+    foreach my $dir ( keys %dirs ) {
+        my $path = AFS::Object::Path->new
+          (
+           path			=> $dir,
+           error		=> "Unable to determine results",
+          );
+        $result->_addPath($path);
     }
 
     $errors++ unless $self->_reap_cmds( allowstatus => 1 );
@@ -822,7 +833,7 @@ sub sysname {
 
     while ( defined($_ = $self->{handle}->getline()) ) {
 
-	if ( /Current sysname is \'?(.*)\'?/ ) {
+	if ( /Current sysname is \'?([^\']+)\'?/ ) {
 	    $result->_setAttribute( sysname => $1 );
 	} elsif ( s/Current sysname list is // ) {
 	    while ( s/\'([^\']+)\'\s*// ) {
