@@ -1,5 +1,5 @@
 #
-# $Id: VOS.pm,v 1.5 2003/08/26 19:17:45 wpm Exp $
+# $Id: VOS.pm,v 3.2 2003/10/08 21:58:22 wpm Exp $
 #
 # (c) 2003 Morgan Stanley and Co.
 # See ..../src/LICENSE for terms of distribution.
@@ -20,9 +20,10 @@ use AFS::Object::VolumeHeader;
 use AFS::Object::VolServer;
 use AFS::Object::FileServer;
 use AFS::Object::Partition;
+use AFS::Object::Transaction;
 
 our @ISA = qw(AFS::Command::Base);
-our $VERSION = '1.0';
+our $VERSION = '1.2';
 
 sub examine {
 
@@ -828,26 +829,73 @@ sub status {
 
     $errors++ unless $self->_exec_cmds();
 
+    my $transaction = undef;
+
     while ( defined($_ = $self->{handle}->getline()) ) {
 
-	#
-	# This is the trivial, normal, and easy case.
-	#
+	chomp;
+
 	if ( /No active transactions/ ) {
 	    $result->_setAttribute( transactions => 0 );
 	    last;
 	}
 
-	#
-	# Ah, if only life were so simple...
-	#
-	# For now, we are going to return nothing other than the total
-	# number of transactions.  Complete parsing of these will have
-	# to wait.
-	#
 	if ( /Total transactions: (\d+)/ ) {
 	    $result->_setAttribute( transactions => $1 );
-	    last;
+	    next;
+	}
+
+	if ( /^-+\s*$/ ) {
+
+	    if ( $transaction ) {
+		$result->_addTransaction($transaction);
+		$transaction = undef;
+	    } else {
+		$transaction = AFS::Object::Transaction->new();
+	    }
+
+	}
+
+	next unless $transaction;
+
+	if ( /transaction:\s+(\d+)/ ) {
+	    $transaction->_setAttribute( transaction => $1 );
+	}
+
+	if ( /created:\s+(.*)$/ ) {
+	    $transaction->_setAttribute( created => $1 );
+	}
+
+	if ( /attachFlags:\s+(.*)$/ ) {
+	    $transaction->_setAttribute( attachFlags => $1 );
+	}
+
+	if ( /volume:\s+(\d+)/ ) {
+	    $transaction->_setAttribute( volume => $1 );
+	}
+
+	if ( /partition:\s+(\S+)/ ) {
+	    $transaction->_setAttribute( partition => $1 );
+	}
+
+	if ( /procedure:\s+(\S+)/ ) {
+	    $transaction->_setAttribute( procedure => $1 );
+	}
+
+	if ( /packetRead:\s+(\d+)/ ) {
+	    $transaction->_setAttribute( packetRead => $1 );
+	}
+
+	if ( /lastReceiveTime:\s+(\d+)/ ) {
+	    $transaction->_setAttribute( lastReceiveTime => $1 );
+	}
+
+	if ( /packetSend:\s+(\d+)/ ) {
+	    $transaction->_setAttribute( packetSend => $1 );
+	}
+
+	if ( /lastSendTime:\s+(\d+)/ ) {
+	    $transaction->_setAttribute( lastSendTime => $1 );
 	}
 
     }
